@@ -266,15 +266,16 @@ seahorse_gkr_list_operation_class_init (SeahorseGkrListOperationClass *klass)
 
 enum {
 	PROP_0,
-	PROP_KEY_TYPE,
-	PROP_KEY_DESC,
-	PROP_LOCATION,
+	PROP_SOURCE_TAG,
+	PROP_SOURCE_LOCATION,
 	PROP_KEYRING_NAME,
-	PROP_KEYRING_INFO
+	PROP_KEYRING_INFO,
+	PROP_IS_DEFAULT
 };
 
 struct _SeahorseGkrKeyringPrivate {
 	gchar *keyring_name;
+	gboolean is_default;
 	
 	gpointer req_info;
 	GnomeKeyringInfo *keyring_info;
@@ -420,7 +421,7 @@ static void
 seahorse_gkr_keyring_init (SeahorseGkrKeyring *self)
 {
 	self->pv = G_TYPE_INSTANCE_GET_PRIVATE (self, SEAHORSE_TYPE_GKR_KEYRING, SeahorseGkrKeyringPrivate);
-	g_object_set (self, "tag", SEAHORSE_GKR_TYPE, NULL);
+	g_object_set (self, "tag", SEAHORSE_GKR_TYPE, "location", SEAHORSE_LOCATION_LOCAL, NULL);
 }
 
 static void
@@ -458,6 +459,9 @@ seahorse_gkr_keyring_set_property (GObject *obj, guint prop_id, const GValue *va
 	case PROP_KEYRING_INFO:
 		seahorse_gkr_keyring_set_info (self, g_value_get_boxed (value));
 		break;
+	case PROP_IS_DEFAULT:
+		seahorse_gkr_keyring_set_is_default (self, g_value_get_boolean (value));
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, prop_id, pspec);
 		break;
@@ -471,13 +475,10 @@ seahorse_gkr_keyring_get_property (GObject *obj, guint prop_id, GValue *value,
 	SeahorseGkrKeyring *self = SEAHORSE_GKR_KEYRING (obj);
 	
 	switch (prop_id) {
-	case PROP_KEY_TYPE:
+	case PROP_SOURCE_TAG:
 		g_value_set_uint (value, SEAHORSE_GKR_TYPE);
 		break;
-	case PROP_KEY_DESC:
-		g_value_set_string (value, _("Passwords"));
-		break;
-	case PROP_LOCATION:
+	case PROP_SOURCE_LOCATION:
 		g_value_set_enum (value, SEAHORSE_LOCATION_LOCAL);
 		break;
 	case PROP_KEYRING_NAME:
@@ -486,6 +487,9 @@ seahorse_gkr_keyring_get_property (GObject *obj, guint prop_id, GValue *value,
 	case PROP_KEYRING_INFO:
 		g_value_set_boxed (value, seahorse_gkr_keyring_get_info (self));
 		break;
+	case PROP_IS_DEFAULT:
+		g_value_set_boolean (value, seahorse_gkr_keyring_get_is_default (self));
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, prop_id, pspec);
 		break;
@@ -511,9 +515,8 @@ seahorse_gkr_keyring_class_init (SeahorseGkrKeyringClass *klass)
 	seahorse_class->refresh = seahorse_gkr_keyring_refresh;
 	seahorse_class->delete = seahorse_gkr_keyring_delete;
 	
-	g_object_class_override_property (gobject_class, PROP_KEY_TYPE, "key-type");
-	g_object_class_override_property (gobject_class, PROP_KEY_DESC, "key-desc");
-	g_object_class_override_property (gobject_class, PROP_LOCATION, "location");
+	g_object_class_override_property (gobject_class, PROP_SOURCE_TAG, "source-tag");
+	g_object_class_override_property (gobject_class, PROP_SOURCE_LOCATION, "source-location");
 
 	g_object_class_install_property (gobject_class, PROP_KEYRING_NAME,
 	           g_param_spec_string ("keyring-name", "Gnome Keyring Name", "Name of keyring.", 
@@ -522,6 +525,10 @@ seahorse_gkr_keyring_class_init (SeahorseGkrKeyringClass *klass)
 	g_object_class_install_property (gobject_class, PROP_KEYRING_INFO,
 	           g_param_spec_boxed ("keyring-info", "Gnome Keyring Info", "Info about keyring.", 
 	                               boxed_type_keyring_info (), G_PARAM_READWRITE));
+	
+	g_object_class_install_property (gobject_class, PROP_IS_DEFAULT,
+	           g_param_spec_boolean ("is-default", "Is default", "Is the default keyring.",
+	                                 FALSE, G_PARAM_READWRITE));
 }
 
 static void 
@@ -575,3 +582,18 @@ seahorse_gkr_keyring_set_info (SeahorseGkrKeyring *self, GnomeKeyringInfo *info)
 	g_object_notify (obj, "keyring-info");
 	g_object_thaw_notify (obj);
 }
+
+gboolean
+seahorse_gkr_keyring_get_is_default (SeahorseGkrKeyring *self)
+{
+	g_return_val_if_fail (SEAHORSE_IS_GKR_KEYRING (self), FALSE);
+	return self->pv->is_default;
+}
+
+void
+seahorse_gkr_keyring_set_is_default (SeahorseGkrKeyring *self, gboolean is_default)
+{
+	g_return_if_fail (SEAHORSE_IS_GKR_KEYRING (self));
+	self->pv->is_default = is_default;
+	g_object_notify (G_OBJECT (self), "is-default");
+}
