@@ -266,18 +266,9 @@ seahorse_context_destroy (SeahorseContext *sctx)
 static gboolean                
 take_source (SeahorseContext *sctx, SeahorseSource *sksrc)
 {
-	SeahorseOperation *operation;
-	
 	g_return_val_if_fail (SEAHORSE_IS_SOURCE (sksrc), FALSE);
 	if (!g_slist_find (sctx->pv->sources, sksrc)) {
 		sctx->pv->sources = g_slist_append (sctx->pv->sources, sksrc);
-		if (seahorse_source_get_location (sksrc) == SEAHORSE_LOCATION_LOCAL && 
-		    sctx->pv->refresh_ops != NULL) {
-			operation = seahorse_source_load (sksrc);
-			g_return_val_if_fail (operation, TRUE);
-			seahorse_multi_operation_take (sctx->pv->refresh_ops, operation);
-			g_signal_emit (sctx, signals[REFRESHING], 0, sctx->pv->refresh_ops);
-		}
 		return TRUE;
 	}
 	
@@ -348,7 +339,7 @@ seahorse_context_find_source (SeahorseContext *sctx, GQuark ktype,
         ks = SEAHORSE_SOURCE (l->data);
         
         if (ktype != SEAHORSE_TAG_INVALID && 
-            seahorse_source_get_ktype (ks) != ktype)
+            seahorse_source_get_tag (ks) != ktype)
             continue;
         
         if (location != SEAHORSE_LOCATION_INVALID && 
@@ -384,7 +375,7 @@ seahorse_context_find_sources (SeahorseContext *sctx, GQuark ktype,
         ks = SEAHORSE_SOURCE (l->data);
         
         if (ktype != SEAHORSE_TAG_INVALID && 
-            seahorse_source_get_ktype (ks) != ktype)
+            seahorse_source_get_tag (ks) != ktype)
             continue;
         
         if (location != SEAHORSE_LOCATION_INVALID && 
@@ -975,7 +966,7 @@ seahorse_context_transfer_objects (SeahorseContext *sctx, GList *objects,
         /* Export from this key source */
         from = seahorse_object_get_source (sobj);
         g_return_val_if_fail (from != NULL, FALSE);
-        ktype = seahorse_source_get_ktype (from);
+        ktype = seahorse_source_get_tag (from);
         
         /* Find a local keysource to import to */
         if (!to) {
@@ -988,7 +979,7 @@ seahorse_context_transfer_objects (SeahorseContext *sctx, GList *objects,
         }
         
         /* Make sure it's the same type */
-        if (ktype != seahorse_source_get_ktype (to)) {
+        if (ktype != seahorse_source_get_tag (to)) {
             /* TODO: How can we warn caller about this. Do we need to? */
             g_warning ("destination is not of type: %s", 
                        g_quark_to_string (ktype));
