@@ -19,7 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
  
-#include <config.h>
+#include "config.h"
  
 #include <stdlib.h>
 #include <string.h>
@@ -28,8 +28,9 @@
 
 #include "seahorse-hkp-source.h"
 
-#include "seahorse-gpgmex.h"
 #include "seahorse-pgp-key.h"
+#include "seahorse-pgp-subkey.h"
+#include "seahorse-pgp-uid.h"
 
 #include "seahorse-gconf.h"
 #include "seahorse-operation.h"
@@ -37,6 +38,7 @@
 #include "seahorse-util.h"
 
 #include "common/seahorse-registry.h"
+#include "common/seahorse-object-list.h"
 
 #include <libsoup/soup.h>
 
@@ -56,9 +58,6 @@
 #define PGP_KEY_BEGIN   "-----BEGIN PGP PUBLIC KEY BLOCK-----"
 #define PGP_KEY_END     "-----END PGP PUBLIC KEY BLOCK-----"
 
-/* Amount of keys to load in a batch */
-#define DEFAULT_LOAD_BATCH 30
-
 #define SOUP_MESSAGE_IS_ERROR(msg) \
     (SOUP_STATUS_IS_TRANSPORT_ERROR((msg)->status_code) || \
      SOUP_STATUS_IS_CLIENT_ERROR((msg)->status_code) || \
@@ -315,7 +314,7 @@ fail_hkp_operation (SeahorseHKPOperation *hop, SoupMessage *msg, const gchar *te
     g_object_get (hop->hsrc, "key-server", &server, NULL);
 
     if (text) {
-        error = g_error_new (HKP_ERROR_DOMAIN, msg ? msg->status_code : 0, text);
+        error = g_error_new (HKP_ERROR_DOMAIN, msg ? msg->status_code : 0, "%s", text);
 
     } else if (msg) {
         /* Make the body lower case, and no tags */
@@ -388,141 +387,165 @@ parse_hkp_date (const gchar *text)
 static GList*
 parse_hkp_index (const gchar *response)
 {
-    /* 
-     * Luckily enough, both the HKP server and NAI HKP interface to their
-     * LDAP server are close enough in output so the same function can
-     * parse them both. 
-     */
+	/* 
+	 * Luckily enough, both the HKP server and NAI HKP interface to their
+	 * LDAP server are close enough in output so the same function can
+	 * parse them both. 
+	 */
 
-    /* pub  2048/<a href="/pks/lookup?op=get&search=0x3CB3B415">3CB3B415</a> 1998/04/03 David M. Shaw &lt;<a href="/pks/lookup?op=get&search=0x3CB3B415">dshaw@jabberwocky.com</a>&gt; */
+	/* pub  2048/<a href="/pks/lookup?op=get&search=0x3CB3B415">3CB3B415</a> 1998/04/03 David M. Shaw &lt;<a href="/pks/lookup?op=get&search=0x3CB3B415">dshaw@jabberwocky.com</a>&gt; */
 
-    gchar **lines, **l;
-    gchar **v;
-    gchar *line, *t;
+	gchar **lines, **l;
+	gchar **v;
+	gchar *line, *t;
     
-    GList *keys = NULL;
-    gpgme_key_t key = NULL;
+	SeahorsePgpKey *key = NULL;
+	GList *keys = NULL;
+	GList *subkeys = NULL;
+	GList *uids = NULL;
+	guint flags;
     
-    lines = g_strsplit (response, "\n", 0);
+	lines = g_strsplit (response, "\n", 0);
     
-    for (l = lines; *l; l++) {
+	for (l = lines; *l; l++) {
 
-        line = *l;
-        dehtmlize(line);
+		line = *l;
+		dehtmlize (line);
 
-        /* Start a new key */
-        if (g_ascii_strncasecmp (line, "pub ", 4) == 0) {
+		/* Start a new key */
+		if (g_ascii_strncasecmp (line, "pub ", 4) == 0) {
             
-            t = line + 4;
-            while (*t && g_ascii_isspace (*t))
-                t++;
+			t = line + 4;
+			while (*t && g_ascii_isspace (*t))
+				t++;
             
-            v = g_strsplit_set (t, " ", 3);
-            if (!v[0] || !v[1] || !v[2]) {
-                g_warning ("Invalid key line from server: %s", line);
+			v = g_strsplit_set (t, " ", 3);
+			if (!v[0] || !v[1] || !v[2]) {
+				g_warning ("Invalid key line from server: %s", line);
                 
-            } else {
-                gchar *fpr = NULL;
-                unsigned int flags = 0;
-                gpgme_pubkey_algo_t algo;
-                gboolean has_uid = TRUE;
+			} else {
+				gchar *fingerprint, *fpr = NULL;
+				const gchar *algo;
+				gboolean has_uid = TRUE;
+				SeahorsePgpSubkey *subkey;
+				
+				flags = SEAHORSE_FLAG_EXPORTABLE;
+       	
+				/* Cut the length and fingerprint */
+				fpr = strchr (v[0], '/');
+				if (fpr == NULL) {
+					g_warning ("couldn't find key fingerprint in line from server: %s", line);
+					fpr = "";
+				} else {
+					*(fpr++) = 0;
+				}
+                
+				/* Check out the key type */
+				switch (g_ascii_toupper (v[0][strlen(v[0]) - 1])) {
+				case 'D':
+					algo = "DSA";
+					break;
+				case 'R':
+					algo = "RSA";
+					break;
+				default:
+					algo = "";
+					break;
+				};
 
-                /* Allocate a new key */
-                key = gpgmex_key_alloc ();
-                g_return_val_if_fail (key != NULL, keys);
-                keys = g_list_prepend (keys, key);
+				/* Format the date for our parse function */
+				g_strdelimit (v[1], "/", '-');
                 
-                /* Cut the length and fingerprint */
-                fpr = strchr (v[0], '/');
-                if (fpr == NULL) {
-                    g_warning ("couldn't find key fingerprint in line from server: %s", line);
-                    fpr = "";
-                } else {
-                    *(fpr++) = 0;
-                }
-                
-                /* Check out the key type */
-                switch (g_ascii_toupper (v[0][strlen(v[0]) - 1])) {
-                case 'D':
-                    algo = GPGME_PK_DSA;
-                    break;
-                case 'R':
-                    algo = GPGME_PK_RSA;
-                    break;
-                default:
-                    algo = 0;
-                    break;
-                };
+				/* Cleanup the UID */
+				g_strstrip (v[2]);
+            
+				if (g_ascii_strcasecmp (v[2], "*** KEY REVOKED ***") == 0) {
+					flags |= SEAHORSE_FLAG_REVOKED;
+					has_uid = FALSE;
+				} 
+				
+				if (key) {
+					seahorse_pgp_key_set_uids (SEAHORSE_PGP_KEY (key), uids);
+					seahorse_object_list_free (uids);
+					seahorse_pgp_key_set_subkeys (SEAHORSE_PGP_KEY (key), subkeys);
+					seahorse_object_list_free (subkeys);
+					uids = subkeys = NULL;
+					key = NULL;
+				}
 
-                /* Format the date for our parse function */
-                g_strdelimit (v[1], "/", '-');
-                
-                /* Cleanup the UID */
-                g_strstrip (v[2]);
-            
-                if (g_ascii_strcasecmp (v[2], "*** KEY REVOKED ***") == 0) {
-                    flags |= GPGMEX_KEY_REVOKED;
-                    has_uid = FALSE;
-                } 
-                
-                /* Add all the info to the key */
-                gpgmex_key_add_subkey (key, fpr, flags, 
-                                       parse_hkp_date (v[1]), 
-                                       0, strtol (v[0], NULL, 10), algo);
+				key = seahorse_pgp_key_new ();
+				keys = g_list_prepend (keys, key);
+		        	g_object_set (key, "location", SEAHORSE_LOCATION_REMOTE, "flags", 
+		        	              flags, NULL);
+		        	
+				/* Add all the info to the key */
+				subkey = seahorse_pgp_subkey_new ();
+				seahorse_pgp_subkey_set_keyid (subkey, fpr);
+				fingerprint = seahorse_pgp_subkey_calc_fingerprint (fpr);
+				seahorse_pgp_subkey_set_fingerprint (subkey, fingerprint);
+				g_free (fingerprint);
+				seahorse_pgp_subkey_set_flags (subkey, flags);
+				seahorse_pgp_subkey_set_created (subkey, parse_hkp_date (v[1]));
+				seahorse_pgp_subkey_set_length (subkey, strtol (v[0], NULL, 10));
+				seahorse_pgp_subkey_set_algorithm (subkey, algo);
+				subkeys = g_list_prepend (subkeys, subkey);
 
-                /* And the UID if one was found */                
-                if (has_uid)
-                    gpgmex_key_add_uid (key, v[2], 0);
-            }
+				/* And the UID if one was found */                
+				if (has_uid) {
+					SeahorsePgpUid *uid = seahorse_pgp_uid_new (v[2]);
+					uids = g_list_prepend (uids, uid);
+				}
+			}
             
-            g_strfreev (v);
+			g_strfreev (v);
             
-        /* A UID for the key */
-        } else if (key && g_ascii_strncasecmp (line, "    ", 4) == 0) {
+		/* A UID for the key */
+		} else if (key && g_ascii_strncasecmp (line, "    ", 4) == 0) {
             
-            g_strstrip (line);
-            gpgmex_key_add_uid (key, line, 0);
+			SeahorsePgpUid *uid;
+			
+			g_strstrip (line);
+			uid = seahorse_pgp_uid_new (line);
+			uids = g_list_prepend (uids, uid);
             
-        /* Signatures */
-        } else if (key && g_ascii_strncasecmp (line, "sig ", 4) == 0) {
+		/* Signatures */
+		} else if (key && g_ascii_strncasecmp (line, "sig ", 4) == 0) {
             
-            /* TODO: Implement signatures */
+			/* TODO: Implement signatures */
             
-        /* Other junk */
-        } else {
-            
-            /* The end of the key */
-            key = NULL;
-        }
-    }
+		} 
+	}
     
-    g_strfreev (lines);
-                        
-    return keys; 
+	g_strfreev (lines);
+
+	if (key) {
+		seahorse_pgp_key_set_uids (SEAHORSE_PGP_KEY (key), uids);
+		seahorse_object_list_free (uids);
+		seahorse_pgp_key_set_subkeys (SEAHORSE_PGP_KEY (key), subkeys);
+		seahorse_object_list_free (subkeys);
+	}
+	
+	return keys; 
 }
 
 static void
-add_key (SeahorseHKPSource *ssrc, gpgme_key_t key)
+add_key (SeahorseHKPSource *ssrc, SeahorsePgpKey *key)
 {
-    SeahorseObject *prev;
-    SeahorsePGPKey *pkey;
-    GQuark keyid;
+	SeahorseObject *prev;
+	GQuark keyid;
        
-    keyid = seahorse_pgp_key_get_cannonical_id (seahorse_pgp_key_get_id (key, 0));
-    prev = seahorse_context_get_object (SCTX_APP (), SEAHORSE_SOURCE (ssrc), keyid);
-    
-    if (prev != NULL) {
-        g_return_if_fail (SEAHORSE_IS_PGP_KEY (prev));
-        gpgmex_combine_keys (SEAHORSE_PGP_KEY (prev)->pubkey, key);
-        seahorse_object_fire_changed (prev, SKEY_CHANGE_UIDS);
-        return;
-    }
+	keyid = seahorse_pgp_key_calc_cannonical_id (seahorse_pgp_key_get_keyid (key));
+	prev = seahorse_context_get_object (SCTX_APP (), SEAHORSE_SOURCE (ssrc), keyid);
+	if (prev != NULL) {
+		g_return_if_fail (SEAHORSE_IS_PGP_KEY (prev));
+		seahorse_pgp_key_set_uids (SEAHORSE_PGP_KEY (prev), seahorse_pgp_key_get_uids (key));
+		seahorse_pgp_key_set_subkeys (SEAHORSE_PGP_KEY (prev), seahorse_pgp_key_get_subkeys (key));
+		return;
+	}
 
-    /* A public key */
-    pkey = seahorse_pgp_key_new (SEAHORSE_SOURCE (ssrc), key, NULL);
-
-    /* Add to context */ 
-    seahorse_context_add_object (SCTX_APP (), SEAHORSE_OBJECT (pkey));
+	/* Add to context */ 
+	seahorse_object_set_source (SEAHORSE_OBJECT (key), SEAHORSE_SOURCE (ssrc));
+	seahorse_context_add_object (SCTX_APP (), SEAHORSE_OBJECT (key));
 }
 
 static void 
@@ -540,12 +563,9 @@ refresh_callback (SoupSession *session, SoupMessage *msg, SeahorseHKPOperation *
     
     keys = parse_hkp_index (msg->response_body->data);
     
-    for (k = keys; k; k = g_list_next (k)) {
-        add_key (hop->hsrc, (gpgme_key_t)(k->data));
-        gpgmex_key_unref ((gpgme_key_t)(k->data));
-    }
-    
-    g_list_free (keys);
+    for (k = keys; k; k = g_list_next (k))
+        add_key (hop->hsrc, SEAHORSE_PGP_KEY (k->data));
+    seahorse_object_list_free (keys);
 
     if (--hop->requests <= 0)
         seahorse_operation_mark_done (SEAHORSE_OPERATION (hop), FALSE, NULL);
@@ -711,11 +731,14 @@ get_callback (SoupSession *session, SoupMessage *msg, SeahorseHKPOperation *hop)
 
 enum {
     PROP_0,
-    PROP_KEY_TYPE,
-    PROP_KEY_DESC
+    PROP_SOURCE_TAG,
+    PROP_SOURCE_LOCATION
 };
 
-G_DEFINE_TYPE (SeahorseHKPSource, seahorse_hkp_source, SEAHORSE_TYPE_SERVER_SOURCE);
+static void seahorse_source_iface (SeahorseSourceIface *iface);
+
+G_DEFINE_TYPE_EXTENDED (SeahorseHKPSource, seahorse_hkp_source, SEAHORSE_TYPE_SERVER_SOURCE, 0,
+                        G_IMPLEMENT_INTERFACE (SEAHORSE_TYPE_SOURCE, seahorse_source_iface));
 
 static void 
 seahorse_hkp_source_init (SeahorseHKPSource *hsrc)
@@ -728,15 +751,42 @@ seahorse_hkp_source_get_property (GObject *object, guint prop_id, GValue *value,
                                   GParamSpec *pspec)
 {
     switch (prop_id) {
-    case PROP_KEY_TYPE:
+    case PROP_SOURCE_TAG:
         g_value_set_uint (value, SEAHORSE_PGP);
         break;
-    case PROP_KEY_DESC:
-        g_value_set_string (value, _("PGP Key"));
+    case PROP_SOURCE_LOCATION:
+        g_value_set_enum (value, SEAHORSE_LOCATION_REMOTE);
         break;
     };        
 }
 
+static void 
+seahorse_hkp_source_set_property (GObject *object, guint prop_id, const GValue *value,
+                                   GParamSpec *pspec)
+{
+
+}
+
+static gboolean
+is_hex_keyid (const gchar *match)
+{
+    const gchar *t;
+    
+    t = match;
+    
+    if (strlen (match) != 8)
+        return FALSE;
+    
+    while (*t != NULL) {
+        if (!((*t >= 0x30 && *t <= 0x39) || (*t >= 0x41 && *t <= 0x46) || (*t >= 0x61 && *t <= 0x66)))
+            return FALSE;
+            
+        t++;
+    }
+    
+    return TRUE;
+}
+
 static SeahorseOperation*
 seahorse_hkp_source_search (SeahorseSource *src, const gchar *match)
 {
@@ -745,6 +795,7 @@ seahorse_hkp_source_search (SeahorseSource *src, const gchar *match)
     GHashTable *form;
     gchar *t;
     SoupURI *uri;
+    gchar hexfpr[11];
     
     g_assert (SEAHORSE_IS_SOURCE (src));
     g_assert (SEAHORSE_IS_HKP_SOURCE (src));
@@ -756,7 +807,15 @@ seahorse_hkp_source_search (SeahorseSource *src, const gchar *match)
     
     form = g_hash_table_new (g_str_hash, g_str_equal);
     g_hash_table_insert (form, "op", "index");
-    g_hash_table_insert (form, "search", (char *)match);
+    
+    if (is_hex_keyid (match)) {
+        strncpy (hexfpr, "0x", 3);
+        strncpy (hexfpr + 2, match, 9);
+        
+        g_hash_table_insert (form, "search", hexfpr);
+    } else 
+        g_hash_table_insert (form, "search", (char *)match);
+        
     soup_uri_set_query_from_form (uri, form);
     g_hash_table_destroy (form);
     
@@ -778,26 +837,6 @@ seahorse_hkp_source_search (SeahorseSource *src, const gchar *match)
     return SEAHORSE_OPERATION (hop);
 }
 
-static SeahorseOperation*
-seahorse_hkp_source_load (SeahorseSource *src, GQuark keyid)
-{
-    SeahorseOperation *op;
-    
-    g_assert (SEAHORSE_IS_SOURCE (src));
-    g_assert (SEAHORSE_IS_HKP_SOURCE (src));
-    
-    op = SEAHORSE_SOURCE_CLASS (seahorse_hkp_source_parent_class)->load (src, keyid);
-    if (op != NULL)
-        return op;
-
-    /* No way to find new all or new keys */
-    if (!keyid)
-        return seahorse_operation_new_complete (NULL);
-
-    /* TODO: Does this actually work? */
-    return seahorse_hkp_source_search (src, seahorse_key_get_rawid (keyid));        
-}
-
 static SeahorseOperation* 
 seahorse_hkp_source_import (SeahorseSource *sksrc, GInputStream *input)
 {
@@ -914,7 +953,7 @@ seahorse_hkp_source_export_raw (SeahorseSource *sksrc, GSList *keyids,
     for (l = keyids; l; l = g_slist_next (l)) {
 
         /* Get the key id and limit it to 8 characters */
-        fpr = (const char*)seahorse_key_get_rawid (GPOINTER_TO_UINT (l->data));
+        fpr = seahorse_pgp_key_calc_rawid (GPOINTER_TO_UINT (l->data));
         len = strlen (fpr);
         if (len > 8)
             fpr += (len - 8);
@@ -949,32 +988,29 @@ static void
 seahorse_hkp_source_class_init (SeahorseHKPSourceClass *klass)
 {
 	GObjectClass *gobject_class;
-	SeahorseSourceClass *key_class;
    
 	gobject_class = G_OBJECT_CLASS (klass);
 	gobject_class->get_property = seahorse_hkp_source_get_property;
-
-	key_class = SEAHORSE_SOURCE_CLASS (klass);
-	key_class->canonize_id = seahorse_pgp_key_get_cannonical_id;
-	key_class->load = seahorse_hkp_source_load;
-	key_class->search = seahorse_hkp_source_search;
-	key_class->import = seahorse_hkp_source_import;
-	key_class->export_raw = seahorse_hkp_source_export_raw;
-
+	gobject_class->set_property = seahorse_hkp_source_set_property;
+	
 	seahorse_hkp_source_parent_class = g_type_class_peek_parent (klass);
 
-	g_object_class_install_property (gobject_class, PROP_KEY_TYPE,
-	        g_param_spec_uint ("key-type", "Key Type", "Key type that originates from this key source.", 
-	                           0, G_MAXUINT, SKEY_UNKNOWN, G_PARAM_READABLE));
+	g_object_class_override_property (gobject_class, PROP_SOURCE_TAG, "source-tag");
+	g_object_class_override_property (gobject_class, PROP_SOURCE_LOCATION, "source-location");
 
-	g_object_class_install_property (gobject_class, PROP_KEY_DESC,
-	        g_param_spec_string ("key-desc", "Key Desc", "Description for keys that originate here.",
-	                             NULL, G_PARAM_READABLE));
-	    
-	seahorse_registry_register_type (NULL, SEAHORSE_TYPE_HKP_SOURCE, "key-source", "remote", SEAHORSE_PGP_STR, NULL);
+	seahorse_registry_register_type (NULL, SEAHORSE_TYPE_HKP_SOURCE, "source", "remote", SEAHORSE_PGP_STR, NULL);
 	seahorse_servers_register_type ("hkp", _("HTTP Key Server"), seahorse_hkp_is_valid_uri);
+	
+	seahorse_registry_register_function (NULL, seahorse_pgp_key_calc_cannonical_id, "canonize", SEAHORSE_PGP_STR, NULL);
 }
 
+static void 
+seahorse_source_iface (SeahorseSourceIface *iface)
+{
+	iface->search = seahorse_hkp_source_search;
+	iface->import = seahorse_hkp_source_import;
+	iface->export_raw = seahorse_hkp_source_export_raw;
+}
 
 /**
  * seahorse_hkp_source_new
